@@ -14,14 +14,12 @@ class Request:
         preset_body=None,
         preset_params=None,
         timeout=10,
-        retry=5,
     ):
         self.id = uuid4().hex
         self.url = url
         self.method = method
         self.headers = headers
         self.timeout = timeout
-        self.retry = retry
         self.preset_body = preset_body or {}
         self.preset_params = preset_params or {}
 
@@ -39,26 +37,18 @@ class Request:
         data = {**self.preset_body, **data}
         params = {**self.preset_params, **params}
 
-        for i in range(self.retry):
-            try:
-                response = requests.request(
-                    self.method,
-                    self.url,
-                    headers=self.headers,
-                    params=params,
-                    json=data,
-                    timeout=self.timeout,
-                )
-            except Exception as e:
-                logging.warn(
-                    f"error while making request {self}, exception is {e}, retry {i}"
-                )
-                time.sleep(3)
-                continue
-            break
-        else:
-            logging.error(
-                f"request failed after retrying"
+        try:
+            response = requests.request(
+                self.method,
+                self.url,
+                headers=self.headers,
+                params=params,
+                json=data,
+                timeout=self.timeout,
+            )
+        except Exception as e:
+            logging.warn(
+                f"error while making request {self}, exception is {e}"
             )
             return None
 
