@@ -4,6 +4,7 @@ import os
 import random
 import shutil
 import signal
+import sys
 import time
 import requests
 import tempfile
@@ -50,10 +51,13 @@ def setup_root(root: str) -> Path:
 
 
 def setup_logger(log_file, level=logging.INFO):
+    stdout_handler = logging.StreamHandler(sys.stdout)
+    file_handler = logging.FileHandler(filename=log_file)
+
     logging.basicConfig(
-        filename=log_file,
         level=level,
         format="[%(asctime)s] %(levelname)s in %(module)s: %(message)s",
+        handlers=[file_handler, stdout_handler],
     )
 
 
